@@ -23,32 +23,32 @@ import Data.Char (isSpace)
 import Data.List (intercalate)
 
 data HashDefine
-	= LineDrop
-		{ name :: String }
-	| Pragma
-		{ name :: String }
+        = LineDrop
+                { name :: String }
+        | Pragma
+                { name :: String }
         | AntiDefined
-		{ name          :: String
-		, linebreaks    :: Int
-		}
-	| SymbolReplacement
-		{ name		:: String
-		, replacement	:: String
-		, linebreaks    :: Int
-		}
-	| MacroExpansion
-		{ name		:: String
-		, arguments	:: [String]
-		, expansion	:: [(ArgOrText,String)]
-		, linebreaks    :: Int
-		}
+                { name          :: String
+                , linebreaks    :: Int
+                }
+        | SymbolReplacement
+                { name          :: String
+                , replacement   :: String
+                , linebreaks    :: Int
+                }
+        | MacroExpansion
+                { name          :: String
+                , arguments     :: [String]
+                , expansion     :: [(ArgOrText,String)]
+                , linebreaks    :: Int
+                }
     deriving (Eq,Show)
 
 -- | 'smart' constructor to avoid warnings from ghc (undefined fields)
 symbolReplacement :: HashDefine
 symbolReplacement =
     SymbolReplacement
-	 { name=undefined, replacement=undefined, linebreaks=undefined }
+         { name=undefined, replacement=undefined, linebreaks=undefined }
 
 -- | Macro expansion text is divided into sections, each of which is classified
 --   as one of three kinds: a formal argument (Arg), plain text (Text),
@@ -60,12 +60,18 @@ data ArgOrText = Arg | Text | Str deriving (Eq,Show)
 expandMacro :: HashDefine -> [String] -> Bool -> String
 expandMacro macro parameters layout =
     let env = zip (arguments macro) parameters
-        replace (Arg,s)  = maybe (error "formal param") id (lookup s env)
-        replace (Str,s)  = maybe (error "formal param") str (lookup s env)
+        replace (Arg,s)  = maybe ("")      id (lookup s env)
+        replace (Str,s)  = maybe (str "") str (lookup s env)
         replace (Text,s) = if layout then s else filter (/='\n') s
         str s = '"':s++"\""
+        checkArity | length (arguments macro) == 1 && length parameters <= 1
+                   || length (arguments macro) == length parameters = id
+                   | otherwise = error ("macro "++name macro++" expected "++
+                                        show (length (arguments macro))++
+                                        " arguments, but was given "++
+                                        show (length parameters))
     in
-    concatMap replace (expansion macro)
+    checkArity $ concatMap replace (expansion macro)
 
 -- | Parse a \#define, or \#undef, ignoring other \# directives
 parseHashDefine :: Bool -> [String] -> Maybe HashDefine
